#[repr(C)]pub struct ProcessHandleStats {
pub handle_count: [u32; 64],
}Fields
handle_count: [u32; 64]Trait Implementations
Sourceimpl Clone for ProcessHandleStats
impl Clone for ProcessHandleStats
Sourcefn clone(&self) -> ProcessHandleStats
fn clone(&self) -> ProcessHandleStats
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ProcessHandleStats
Sourceimpl Debug for ProcessHandleStats
impl Debug for ProcessHandleStats
Sourceimpl Default for ProcessHandleStats
impl Default for ProcessHandleStats
impl Eq for ProcessHandleStats
Sourceimpl FromBytes for ProcessHandleStats
impl FromBytes for ProcessHandleStats
Sourcefn read_from_prefix(
source: &[u8],
) -> Result<(Self, &[u8]), SizeError<&[u8], Self>>where
Self: Sized,
fn read_from_prefix(
source: &[u8],
) -> Result<(Self, &[u8]), SizeError<&[u8], Self>>where
Self: Sized,
Sourceimpl FromZeros for ProcessHandleStats
impl FromZeros for ProcessHandleStats
Sourcefn new_zeroed() -> Selfwhere
Self: Sized,
fn new_zeroed() -> Selfwhere
Self: Sized,
Creates an instance of
Self from zeroed bytes. Read moreSourcefn new_box_zeroed() -> Result<Box<Self>, AllocError>where
Self: Sized,
fn new_box_zeroed() -> Result<Box<Self>, AllocError>where
Self: Sized,
Creates a
Box<Self> from zeroed bytes. Read moreSourcefn new_vec_zeroed(len: usize) -> Result<Vec<Self>, AllocError>where
Self: Sized,
fn new_vec_zeroed(len: usize) -> Result<Vec<Self>, AllocError>where
Self: Sized,
Creates a
Vec<Self> from zeroed bytes. Read moreSourcefn extend_vec_zeroed(
v: &mut Vec<Self>,
additional: usize,
) -> Result<(), AllocError>where
Self: Sized,
fn extend_vec_zeroed(
v: &mut Vec<Self>,
additional: usize,
) -> Result<(), AllocError>where
Self: Sized,
Extends a
Vec<Self> by pushing additional new items onto the end of
the vector. The new items are initialized with zeros. Read moreimpl Immutable for ProcessHandleStats
Sourceimpl PartialEq for ProcessHandleStats
impl PartialEq for ProcessHandleStats
Sourcefn eq(&self, other: &ProcessHandleStats) -> bool
fn eq(&self, other: &ProcessHandleStats) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ProcessHandleStats
Sourceimpl TryFromBytes for ProcessHandleStats
impl TryFromBytes for ProcessHandleStats
Sourcefn try_read_from_bytes(
source: &[u8],
) -> Result<Self, ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_bytes(
source: &[u8],
) -> Result<Self, ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
Sourcefn try_read_from_prefix(
source: &[u8],
) -> Result<(Self, &[u8]), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_prefix(
source: &[u8],
) -> Result<(Self, &[u8]), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
Sourcefn try_read_from_suffix(
source: &[u8],
) -> Result<(&[u8], Self), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,
fn try_read_from_suffix(
source: &[u8],
) -> Result<(&[u8], Self), ConvertError<Infallible, SizeError<&[u8], Self>, ValidityError<&[u8], Self>>>where
Self: Sized,