pub struct Rights(/* private fields */);Expand description
Rights associated with a handle.
See rights for more information.
Implementations
Sourceimpl Rights
impl Rights
pub const NONE: Self
pub const DUPLICATE: Self
pub const TRANSFER: Self
pub const READ: Self
pub const WRITE: Self
pub const EXECUTE: Self
pub const MAP: Self
pub const GET_PROPERTY: Self
pub const SET_PROPERTY: Self
pub const ENUMERATE: Self
pub const DESTROY: Self
pub const SET_POLICY: Self
pub const GET_POLICY: Self
pub const SIGNAL: Self
pub const SIGNAL_PEER: Self
pub const WAIT: Self
pub const INSPECT: Self
pub const MANAGE_JOB: Self
pub const MANAGE_PROCESS: Self
pub const MANAGE_THREAD: Self
pub const APPLY_PROFILE: Self
pub const MANAGE_SOCKET: Self
pub const OP_CHILDREN: Self
pub const RESIZE: Self
pub const ATTACH_VMO: Self
pub const MANAGE_VMO: Self
pub const SAME_RIGHTS: Self
pub const BASIC: Self
pub const IO: Self
pub const PROPERTY: Self
pub const POLICY: Self
pub const RESOURCE_BASIC: Self
pub const CHANNEL_DEFAULT: Self
pub const VMO_DEFAULT: Self
Sourceimpl Rights
impl Rights
Sourcepub const fn bits(&self) -> zx_rights_t
pub const fn bits(&self) -> zx_rights_t
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: zx_rights_t) -> Option<Self>
pub const fn from_bits(bits: zx_rights_t) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: zx_rights_t) -> Self
pub const fn from_bits_truncate(bits: zx_rights_t) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: zx_rights_t) -> Self
pub const fn from_bits_retain(bits: zx_rights_t) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Rights
impl Rights
Sourcepub const fn iter(&self) -> Iter<Rights>
pub const fn iter(&self) -> Iter<Rights>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Rights>
pub const fn iter_names(&self) -> IterNames<Rights>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.