pub struct Signals(/* private fields */);Expand description
Signals that can be waited upon.
See Objects and signals in the Zircon kernel documentation. Note: the names of signals are still in flux.
Implementations
Sourceimpl Signals
impl Signals
pub const NONE: Self
pub const OBJECT_ALL: Self
pub const USER_ALL: Self
pub const OBJECT_0: Self
pub const OBJECT_1: Self
pub const OBJECT_2: Self
pub const OBJECT_3: Self
pub const OBJECT_4: Self
pub const OBJECT_5: Self
pub const OBJECT_6: Self
pub const OBJECT_7: Self
pub const OBJECT_8: Self
pub const OBJECT_9: Self
pub const OBJECT_10: Self
pub const OBJECT_11: Self
pub const OBJECT_12: Self
pub const OBJECT_13: Self
pub const OBJECT_14: Self
pub const OBJECT_15: Self
pub const OBJECT_16: Self
pub const OBJECT_17: Self
pub const OBJECT_18: Self
pub const OBJECT_19: Self
pub const OBJECT_20: Self
pub const OBJECT_21: Self
pub const OBJECT_22: Self
pub const USER_0: Self
pub const USER_1: Self
pub const USER_2: Self
pub const USER_3: Self
pub const USER_4: Self
pub const USER_5: Self
pub const USER_6: Self
pub const USER_7: Self
pub const OBJECT_READABLE: Self
pub const OBJECT_WRITABLE: Self
pub const OBJECT_PEER_CLOSED: Self
pub const HANDLE_CLOSED: Self
pub const EVENT_SIGNALED: Self
pub const EVENTPAIR_SIGNALED: Self
pub const EVENTPAIR_PEER_CLOSED: Self
pub const TASK_TERMINATED: Self
pub const CHANNEL_READABLE: Self
pub const CHANNEL_WRITABLE: Self
pub const CHANNEL_PEER_CLOSED: Self
pub const CLOCK_STARTED: Self
pub const CLOCK_UPDATED: Self
pub const COUNTER_SIGNALED: Self
pub const COUNTER_POSITIVE: Self
pub const COUNTER_NON_POSITIVE: Self
pub const SOCKET_READABLE: Self
pub const SOCKET_WRITABLE: Self
pub const SOCKET_PEER_CLOSED: Self
pub const SOCKET_PEER_WRITE_DISABLED: Self
pub const SOCKET_WRITE_DISABLED: Self
pub const SOCKET_READ_THRESHOLD: Self
pub const SOCKET_WRITE_THRESHOLD: Self
pub const RESOURCE_DESTROYED: Self
pub const RESOURCE_READABLE: Self
pub const RESOURCE_WRITABLE: Self
pub const RESOURCE_CHILD_ADDED: Self
pub const FIFO_READABLE: Self
pub const FIFO_WRITABLE: Self
pub const FIFO_PEER_CLOSED: Self
pub const IOB_PEER_CLOSED: Self
pub const IOB_SHARED_REGION_UPDATED: Self
pub const JOB_TERMINATED: Self
pub const JOB_NO_JOBS: Self
pub const JOB_NO_PROCESSES: Self
pub const PROCESS_TERMINATED: Self
pub const THREAD_TERMINATED: Self
pub const THREAD_RUNNING: Self
pub const THREAD_SUSPENDED: Self
pub const LOG_READABLE: Self
pub const LOG_WRITABLE: Self
pub const TIMER_SIGNALED: Self
pub const VMO_ZERO_CHILDREN: Self
pub const VIRTUAL_INTERRUPT_UNTRIGGERED: Self
Sourceimpl Signals
impl Signals
Sourcepub const fn bits(&self) -> zx_signals_t
pub const fn bits(&self) -> zx_signals_t
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: zx_signals_t) -> Option<Self>
pub const fn from_bits(bits: zx_signals_t) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: zx_signals_t) -> Self
pub const fn from_bits_truncate(bits: zx_signals_t) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: zx_signals_t) -> Self
pub const fn from_bits_retain(bits: zx_signals_t) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Signals
impl Signals
Sourcepub const fn iter(&self) -> Iter<Signals>
pub const fn iter(&self) -> Iter<Signals>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Signals>
pub const fn iter_names(&self) -> IterNames<Signals>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.