WaitItem

Struct WaitItem 

pub struct WaitItem<'a> { /* private fields */ }
A “wait item” containing a handle reference and information about what signals to wait on, and, on return from object_wait_many, which are pending.

Returned from wait_item() methods on handle newtypes.

ABI-compatible with zx_wait_item_t.

Implementations

Source

impl<'a> WaitItem<'a>

pub fn handle(&self) -> HandleRef<'a>

Returns a reference to the contained handle, if any.

pub fn waiting_for(&self) -> Signals

Returns the signals that this WaitItem is asing the kernel to wait for.

pub fn pending(&self) -> Signals

Returns the set of signals pending as written by object_wait_many.